%global _version        2020-12-R3

## {Local macros...
%global cfgdir          %_sysconfdir/%name
%global _rpmversion     %(echo %_version | tr - .)
## ...local macros}

%{!?apply:%global  apply(p:n:b:) %patch%%{-n:%%{-n*}} %%{-p:-p%%{-p*}} %%{-b:-b%%{-b*}} \
%nil}

Summary:        WLAN detector, sniffer and IDS
Name:           kismet
Version:        %_rpmversion
Release:        %mkrel 14
Group:          Networking/Other
License:        GPLv2+
URL:            https://www.kismetwireless.net/
Source0:        https://www.kismetwireless.net/code/%{name}-%_version.tar.xz
Source1:        README.urpmi

Patch0:         kismet-include.patch
Patch1:         kismet-install.patch

BuildRequires:  pkgconfig(ncurses)
BuildRequires:  libpcap-devel
BuildRequires:  libnl3-devel
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  diffutils
BuildRequires:  libmicrohttpd-devel
BuildRequires:  protobuf-devel
BuildRequires:  protobuf-c-devel
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  lm_sensors-devel
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  python3-setuptools

# (doktor5000) required for the creation of the group to run suid capture helper
Requires(pre):    rpm-helper
Requires(post):   rpm-helper
Requires(preun):  rpm-helper
Requires(postun): rpm-helper

%description
Kismet is an 802.11 layer2 wireless network detector, sniffer, and
intrusion detection system. Kismet will work with any wireless card
which supports raw monitoring (rfmon) mode, and can sniff 802.11b,
802.11a, and 802.11g traffic.

Kismet identifies networks by passively collecting packets and detecting
standard named networks, detecting (and given time, decloaking) hidden
networks, and inferring the presence of nonbeaconing networks via data
traffic.

%prep
%setup -qn %{name}-%{_version}

%patch -P 0 -p0
%patch -P 1 -p0

sed -i 's!\$(prefix)/lib/!%{_libdir}/!g' plugin-*/Makefile


# set our 'kismet' user, disable GPS and log into %%logdir by
# default
sed -i \
    -e '\!^ouifile=/etc/manuf!d' \
    -e '\!^ouifile=/usr/share/wireshark/wireshark/manuf!d' \
    conf/kismet.conf

%build

export ac_cv_lib_uClibcpp_main=no # we do not want to build against uClibc++, even when available
export LDFLAGS='-Wl,--as-needed'
%configure \
           --sysconfdir=%cfgdir \
           CXXFLAGS="$RPM_OPT_FLAGS -D__STDC_FORMAT_MACROS"

%make_build

sed -i s/2019-08-GIT/%{version}-%{release}%{?dist}/g packaging/kismet.pc

%install
BIN=$RPM_BUILD_ROOT/%{_bindir} ETC=$RPM_BUILD_ROOT/etc %make_install

# Currently broken (maybe due to python version)
rm -f %{buildroot}/%{_bindir}/kismet_cap_sdr_rtla*

%pre
# (doktor5000) add kismet group to run suid capture helper
%_pre_groupadd %{name}

%postun
%_postun_groupdel %{name}

%files
%doc CHANGELOG README* docs/
%dir %attr(0755,root,root) %cfgdir
%config(noreplace) %cfgdir/*
%{_bindir}/kismet
%attr(4750,root,%{name}) %{_bindir}/kismet_cap*
%{_bindir}/kismetdb*
%{_bindir}/kismet_discovery
%{_bindir}/kismet_server
%{_datadir}/kismet
%{_libdir}/pkgconfig/kismet.pc
%{python3_sitelib}/Kismet*



%changelog
* Sun Jul 06 2025 umeabot <umeabot> 2020.12.R3-14.mga10
+ Revision: 2247387
- Mageia 10 Mass Rebuild

* Tue Mar 11 2025 daviddavid <daviddavid> 2020.12.R3-13.mga10
+ Revision: 2162672
- rebuild for new protobuf 30.0

* Sun Mar 09 2025 daviddavid <daviddavid> 2020.12.R3-12.mga10
+ Revision: 2162112
- rebuild for python 3.13
+ pterjan <pterjan>
- Rebuild for patchN deprecation

* Sun Feb 11 2024 daviddavid <daviddavid> 2020.12.R3-10.mga10
+ Revision: 2040190
- rebuild for py3.12

* Thu Dec 22 2022 wally <wally> 2020.12.R3-9.mga9
+ Revision: 1925783
- rebuild for protobuf 21.12

* Tue Oct 25 2022 papoteur <papoteur> 2020.12.R3-8.mga9
+ Revision: 1899226
- Rebuild for libwebsockets 4.3.2

* Tue Apr 05 2022 umeabot <umeabot> 2020.12.R3-7.mga9
+ Revision: 1844849
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 2020.12.R3-6.mga9
+ Revision: 1787338
- rebuild for python-3.10

* Tue Dec 28 2021 wally <wally> 2020.12.R3-5.mga9
+ Revision: 1764985
- rebuild for protobuf 3.19.1

* Tue Apr 20 2021 daviddavid <daviddavid> 2020.12.R3-4.mga9
+ Revision: 1717601
- rebuild for new libwebsockets 4.2.0

* Mon Mar 22 2021 daviddavid <daviddavid> 2020.12.R3-3.mga9
+ Revision: 1707843
- rebuild for python 3.9

* Fri Jan 15 2021 pterjan <pterjan> 2020.12.R3-2.mga8
+ Revision: 1671911
- Drop broken python capture tools

* Fri Jan 15 2021 pterjan <pterjan> 2020.12.R3-1.mga8
+ Revision: 1671910
- Fix permissions to have capture helpers suid
- Update to 2020-12-R3

* Thu Feb 13 2020 umeabot <umeabot> 2016.07.R1-3.mga8
+ Revision: 1513744
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 2016.07.R1-2.mga7
+ Revision: 1298562
- Mageia 7 Mass Rebuild

* Fri Sep 15 2017 guillomovitch <guillomovitch> 2016.07.R1-1.mga7
+ Revision: 1154144
- new version 2016-07-R1
- enable btscan and spectools plugins
- don't mess with configuration file during post-installation

* Tue Feb 09 2016 umeabot <umeabot> 2013.03.R1b-5.mga6
+ Revision: 952578
- Mageia 6 Mass Rebuild

* Wed Mar 11 2015 doktor5000 <doktor5000> 2013.03.R1b-4.mga5
+ Revision: 818422
- bump release to be able to submit to core/release

* Tue Mar 10 2015 doktor5000 <doktor5000> 2013.03.R1b-3.mga5
+ Revision: 818312
+ rebuild (emptylog)

* Tue Mar 03 2015 doktor5000 <doktor5000> 2013.03.R1b-2.mga5
+ Revision: 817551
- fix permissions of SUID kismet_capture binary
- rephrased section and fixed typo in README.urpmi
- dropped Recommends on wireshark, flite and festival

* Mon Mar 02 2015 doktor5000 <doktor5000> 2013.03.R1b-1.mga5
+ Revision: 817363
- new version 2013-03-R1b
- added SUID kismet_capture binary to allow capturing as non-root user
  o added README.urpmi to document two ways of using kismet
  o add necessary kismet group via rpm-helper
  o use %%serverbuild macro to build kismet due to the SUID binary
- enabled new alertsyslog plugin
- reenabled AutoWEP plugin
- added Recommends on wireshark for IEEE OUI file for automatic NIC MAC lookup
- added Recommends on flite & festival to enable speech output on kismet server

* Wed Oct 15 2014 umeabot <umeabot> 2011.03.R2-7.mga5
+ Revision: 741240
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2011.03.R2-6.mga5
+ Revision: 681095
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2011.03.R2-5.mga4
+ Revision: 506681
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2011.03.R2-4.mga3
+ Revision: 356249
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Mar 20 2012 tmb <tmb> 2011.03.R2-3.mga3
+ Revision: 225013
- build against libnl3
+ doktor5000 <doktor5000>
- fix order of options in sed call in %%post

* Wed Aug 31 2011 doktor5000 <doktor5000> 2011.03.R2-1.mga2
+ Revision: 137314
- new version 2011-03-R2, switching to Newcore
- change versioning scheme to represent upstream versioning
- build additional plugins autowep and ptw, enabling aircrack integration
- remove unused BuildRequire glib-devel
- removed obsolete README.Mandriva
- fix license to GPLv2+
- drop obsolete fix.h header
- drop obsolete patches
- imported package kismet


* Thu Jul 15 2010 Funda Wang <fwang@mandriva.org> 3.1.0805291-5mdv2011.0
+ Revision: 553467
- rebuild for new imagmagick

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 3.1.0805291-4mdv2010.1
+ Revision: 503705
- rebuild for new gmp

* Thu Jan 14 2010 Funda Wang <fwang@mandriva.org> 3.1.0805291-3mdv2010.1
+ Revision: 491376
- add patch from gentoo to have it built

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Wed Mar 25 2009 Pascal Terjan <pterjan@mandriva.org> 3.1.0805291-2mdv2009.1
+ Revision: 361058
- Fix format-security error

* Wed Oct 29 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.0805291-1mdv2009.1
+ Revision: 298591
- 2008-05-R1
- drop redundant patches
- fix build
- rebuilt against libpcap-1.0.0

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild
    - fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.070101b-4mdv2008.1
+ Revision: 167678
- rebuilt against new imagemagick libs

* Tue Jan 08 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.070101b-3mdv2008.1
+ Revision: 146501
- rebuilt against new imagemagick libs (6.3.7)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Sep 05 2007 Michael Scherer <misc@mandriva.org> 3.1.070101b-2mdv2008.0
+ Revision: 79859
- rebuild for libexpat

* Mon May 07 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.1.070101b-1mdv2008.0
+ Revision: 24872
- Made patch 64bits_castfix to fix x86_64 build issue.
- Updated to 2007-01-R1b.


* Thu Mar 22 2007 Michael Scherer <misc@mandriva.org> 3.1.060413-2mdv2007.1
+ Revision: 147864
- rebuild for new libmagick
- Import kismet

* Fri May 19 2006 Emmanuel Andry <eandry@mandriva.org> 3.1.060413-1mdk
- 2006-04-R1
- Change summary and description for 802.11g support
- Fix README.Mandrake
- added gps support

* Mon Dec 26 2005 Nicolas Lécureuil <neoclust@mandriva.org> 3.1.050815-2mdk
- Remove redundant buildRequires

* Sun Sep 11 2005 Michael Scherer <misc@mandriva.org> 3.1.050815-1mdk
- mkrel
- 2005-08-R1

* Thu Aug 25 2005 Oden Eriksson <oeriksson@mandriva.com> 3.1.050630-3mdk
- rebuilt against new Magick libs

* Tue Aug 16 2005 Pascal Terjan <pterjan@mandriva.org> 3.1.050630-2mdk
- rebuild for disappeared libdpstk.so.1

* Fri Jul 01 2005 Lenny Cartier <lenny@mandriva.com> 3.1.050630-1mdk
- 20050630

* Mon Mar 21 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 3.1.041001-4mdk
- Rebuild for new ImageMagick

* Fri Feb 25 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 3.1.041001-3mdk
- Rebuild for new ImageMagick

* Wed Nov 17 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.1.041001-2mdk
- add BuildRequires: flex bison

* Wed Nov 03 2004 Pascal Terjan <pterjan@mandrake.org> 3.1.041001-1mdk
- 2004-10-R1
- drop patches 0, 1 and 2

* Thu Aug 05 2004 Michael Scherer <misc@mandrake.org> 3.1.040401-4mdk 
- rebuild for ImageMagick, patch 2

* Wed Jul 07 2004 Michael Scherer <misc@mandrake.org> 3.1.040401-3mdk 
- rebuild for ImageMagick
- fix header inclusion

* Mon Jun 07 2004 Michael Scherer <misc@mandrake.org> 3.1.040401-2mdk 
- rebuild for new gcc

* Fri Apr 09 2004 Michael Scherer <misc@mandrake.org> 3.1.040401-1mdk 
- new version ( 2004-04-R1 )
- fixed and explain the versionning scheme

